==> dynamsoft_capture_vision_flutter-1.2.2.tar.gz: README.md <==
# Dynamsoft Capture Vision Flutter Edition

<a href="https://www.dynamsoft.com/capture-vision/docs/introduction/">Dynamsoft Capture Vision (DCV) </a> is an aggregating SDK of a series of specific functional products including:

- Dynamsoft Camera Enhancer (DCE) which provides camera enhancements and UI configuration APIs.
- Dynamsoft Barcode Reader (DBR) which provides barcode decoding algorithm and APIs.
- Dynamsoft Label Recognizer (DLR) which provides label content recognizing algorithm and APIs.
- Dynamsoft Document Normalizer (DDN) which provides document scanning algorithms and APIs.

>Note: DCV Flutter edition currently only includes DCE and DBR modules. DLR and DDN modules are still under development and will be included in the future.

## Getting Started

In <a href="https://www.dynamsoft.com/capture-vision/docs/programming/flutter/user-guide/barcode-reader.html" target="_blank">this guide</a>, you will learn step by step how to integrate the barcode reading capabilities of Dynamsoft Capture Vision Flutter SDK into your App.

## Samples

You can view all the DCV Flutter samples via the following links:

- <a href = "https://github.com/Dynamsoft/capture-vision-flutter-samples/tree/main/barcode_reader_simple_sample" target = "_blank" >Barcode reader simple sample</a>

## API References

View the API reference of DCV Flutter Edition to explore the full feature of DCV:

- <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/?ver=latest" target = "_blank" >DCV API Reference - Flutter Edition</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/barcode-reader.html?ver=latest" target = "_blank" >DCVBarcodeReader Class</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/camera-enhancer.html?ver=latest" target = "_blank" >DCVCameraEnhancer Class</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/camera-view.html?ver=latest" target = "_blank" >DCVCameraView Class</a>

## License

- You can also request an extension for your trial license in the [customer portal](https://www.dynamsoft.com/customer/license/trialLicense?product=dbr&utm_source=github)

## Contact

https://www.dynamsoft.com/company/contact/

==> dynamsoft_capture_vision_flutter-1.3.0.tar.gz: README.md <==
# Decode Barcodes With Dynamsoft Capture Vision Flutter Edition

<a href="https://www.dynamsoft.com/capture-vision/docs/introduction/">Dynamsoft Capture Vision (DCV) </a> is an aggregating SDK of a series of specific functional products including:

- Dynamsoft Camera Enhancer (DCE) which provides camera enhancements and UI configuration APIs.
- Dynamsoft Barcode Reader (DBR) which provides barcode decoding algorithm and APIs.
- Dynamsoft Label Recognizer (DLR) which provides label content recognizing algorithm and APIs.
- Dynamsoft Document Normalizer (DDN) which provides document scanning algorithms and APIs.

>Note: DCV Flutter edition currently only supports barcode reading feature.

## Features

### Supports the majority of barcode types

- OneD Barcodes
  - Code 39 (including Code 39 Extended)
  - Code 93
  - Code 128
  - Codabar
  - Interleaved 2 of 5
  - EAN-8
  - EAN-13
  - UPC-A
  - UPC-E
  - Industrial 2 of 5
  - MSI (Modified Plessey)
  - Code 11
- 2D Barcodes
  - QR Code (including Micro QR Code and Model 1)
  - Data Matrix
  - PDF417 (including Micro PDF417)
  - Aztec Code
  - MaxiCode (mode 2-5)
  - DotCode
- GS1 DataBar
- GS1 Composite Code
- Patch Code
- Pharmacode
- Postal Code

### Multiple Barcodes Scanning

The library supports scanning multiple barcodes at the same time. You can use the `DBRRuntimeSettings.expectedBarcodeCount` to configure the settings.

### High Barcode Decoding Speed, Accuracy and Readability

- Blurry barcodes
- Inverted barcodes

![Inverted barcode](https://www.dynamsoft.com/webres/wwwroot/images/resources/inverted-barcodes.png)

- Deformed barcodes

![Deformed barcode](https://www.dynamsoft.com/webres/wwwroot/images/resources/deformed-barcodes.png)

- Damaged barcodes

### Customizable for different Scenarios

The SDK is designed to be flexible and customizable to cover different scenarios. If are not satisfied with the current performance, you can [contact us](https://www.dynamsoft.com/contact/) for further support.

## Getting Started

In <a href="https://www.dynamsoft.com/capture-vision/docs/programming/flutter/user-guide/barcode-reader.html" target="_blank">this guide</a>, you will learn step by step how to integrate the barcode reading capabilities of Dynamsoft Capture Vision Flutter SDK into your App.

## Samples

You can view all the DCV Flutter samples via the following links:

- <a href = "https://github.com/Dynamsoft/capture-vision-flutter-samples/tree/main/barcode_reader_simple_sample" target = "_blank" >Barcode reader simple sample</a>

## API References

View the API reference of DCV Flutter Edition to explore the full feature of DCV:

- <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/?ver=latest" target = "_blank" >DCV API Reference - Flutter Edition</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/barcode-reader.html?ver=latest" target = "_blank" >DCVBarcodeReader Class</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/camera-enhancer.html?ver=latest" target = "_blank" >DCVCameraEnhancer Class</a>
  - <a href = "https://www.dynamsoft.com/capture-vision/docs/programming/flutter/api-reference/camera-view.html?ver=latest" target = "_blank" >DCVCameraView Class</a>

## License

- You can also request an extension for your trial license in the [customer portal](https://www.dynamsoft.com/customer/license/trialLicense?product=dbr&utm_source=github)

## Contact

https://www.dynamsoft.com/company/contact/
